#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03-17
#
# Check Point Firewall connections metrics plugins
# checkpoint_fw_connections
#
# 2023-03-04: moved metrics file from ~/local/share/check_mk/... to ~/local/lib/check_mk/...
#             added predictive metrics
# 2023-05-29: added wato dummy for checkpoint_connections
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info,
    check_metrics,
)

# for predictive monitoring
check_metrics["check_mk-checkpoint_fw_connections"] = {
    "predict_checkpoint_fw_connections_fwcurrentnumconn": {"auto_graph": False},
    "predict_checkpoint_fw_connections_relative": {"auto_graph": False},
}
metric_info['predict_checkpoint_fw_connections_fwcurrentnumconn'] = {
    'title': _('_Predicted connections (absolute)'),
    'unit': 'count',
    'color': '26/b',
}

metric_info['predict_checkpoint_fw_connections_relative'] = {
    'title': _('_Predicted connections (relative)'),
    'unit': '%',
    'color': '36/b',
}
#

# normal metrics
metric_info['checkpoint_fw_connections_fwconnectionstcp'] = {
    'title': _('TCP connections'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_fw_connections_fwconnectionsudp'] = {
    'title': _('UDP connections'),
    'unit': '1/s',
    'color': '25/a',
}
metric_info['checkpoint_fw_connections_fwconnectionsicmp'] = {
    'title': _('ICMP connections'),
    'unit': '1/s',
    'color': '31/a',
}
metric_info['checkpoint_fw_connections_fwconnectionsother'] = {
    'title': _('Other connections'),
    'unit': '1/s',
    'color': '41/a',
}
metric_info['checkpoint_fw_connections_fwconnectionssum'] = {
    'title': _('Total connections'),
    'unit': '1/s',
    'color': '15/a',
}
metric_info['checkpoint_fw_connections_fwconnectionrate'] = {
    'title': _('Connections rate'),
    'unit': '1/s',
    'color': '22/a',
}

metric_info['checkpoint_fw_connections_fwcurrentnumconn'] = {
    'title': _('Current connections'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['checkpoint_fw_connections_fwpeaknumconn'] = {
    'title': _('Peak Connections'),
    'unit': 'count',
    'color': '16/a',
}

metric_info['checkpoint_fw_connections_relative'] = {
    'title': _('Connections relative'),
    'unit': '%',
    'color': '36/a',
}

graph_info['checkpoint_fw_connections_fwpeaknumconn'] = {
    'title': _('Check Point Firewall Connections absolute'),
    'metrics': [
        ('predict_checkpoint_fw_connections_fwcurrentnumconn', 'line'),
        ('checkpoint_fw_connections_fwcurrentnumconn', 'area'),
        ('checkpoint_fw_connections_fwpeaknumconn', 'line'),
    ],
    'scalars': [
        ('checkpoint_fw_connections_fwcurrentnumconn:crit', _('crit')),
        ('checkpoint_fw_connections_fwcurrentnumconn:warn', _('warn')),
    ],
    'optional_metrics': [
       'predict_checkpoint_fw_connections_fwcurrentnumconn',
    ],
}

graph_info['checkpoint_fw_connections_relative'] = {
    'title': _('Check Point Firewall Connections relative to connection table limit'),
    'metrics': [
        ('predict_checkpoint_fw_connections_relative', 'line'),
        ('checkpoint_fw_connections_relative', 'area'),
    ],
    'scalars': [
        ('checkpoint_fw_connections_relative:crit', _('crit')),
        ('checkpoint_fw_connections_relative:warn', _('warn')),
    ],
    'range': (0, 110),
    'optional_metrics': [
        'predict_checkpoint_fw_connections_relative',
    ],
}

graph_info['checkpoint_fw_connections_fwconnectionstcp'] = {
    'title': _('Check Point Firewall Connections per second'),
    'metrics': [
        ('checkpoint_fw_connections_fwconnectionsother', 'stack'),
        ('checkpoint_fw_connections_fwconnectionsicmp', 'stack'),
        ('checkpoint_fw_connections_fwconnectionsudp', 'stack'),
        ('checkpoint_fw_connections_fwconnectionstcp', 'stack'),
        ('checkpoint_fw_connections_fwconnectionssum', 'line'),
        ('checkpoint_fw_connections_fwconnectionrate', 'line'),
    ],
}

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['checkpoint_fw_connections_relative'],
        'total': 100,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fw_connections_fwconnectionrate',
        'half_value': 1000.0,
        'exponent': 2,
    },
]))

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fw_connections_fwcurrentnumconn',
        'half_value': 100000.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fw_connections_fwconnectionrate',
        'half_value': 1000.0,
        'exponent': 2,
    },
]))
